#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in 

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "Não execute o script app_upgrade diretamente.  Para atualizar um aplicativo, execute um dos seguintes comandos:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Use -help para obter uma descrição completa dos comandos acima."
;;

INVALID_START_DIR )
echo ""
echo "Exceto ao usar o parâmetro -help, não é possível executar o script $2 a partir de um diretório que não o $3"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "O arquivo '$2' contém os valores de parâmetro para o script de atualização."
echo "Se for necessário modificar qualquer valor de parâmetro padrão, é possível editar estes arquivos ou especificar os valores de parâmetro como argumentos de linha de comandos para os scripts de atualização."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "O seguinte conjunto de arquivos contém os valores de parâmetro padrão para a atualização de um aplicativo.  Se precisar modificar algum dos valores de parâmetro padrão, será possível editar esses arquivos ou especificar os valores de parâmetro como argumentos da linha de comandos para os scripts de atualização."
echo "- DM upgrade:   $2/params/dm_params$3.sh"
echo "- VVC upgrade:  $2/params/vvc_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "Não foi especificado nenhum tipo de aplicativo.  Para atualizar o aplicativo, execute um dos seguintes comandos:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Use -help para obter uma descrição completa dos comandos acima."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 não é um tipo de aplicativo válido.  Para atualizar o aplicativo, execute um dos seguintes comandos:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Use -help para obter uma descrição completa dos comandos acima."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Valor ausente para o parâmetro $2."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "O diretório $3, especificado para o parâmetro $2, não existe ou não é válido."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "O diretório $3 especificado para o parâmetro $2 deve ser um caminho absoluto."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "O arquivo $3, especificado para o parâmetro $2, não existe ou não é válido."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 é um valor inválido para o parâmetro $2."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 é um parâmetro desconhecido."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Parâmetro de diretório inicial $2 ausente."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "O diretório $2 não existe ou não é válido."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "Não é possível localizar o comando repotools '$2' do aplicativo."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o diretório de configuração antigo do servidor; por exemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "Não é possível localizar o comando repotools '$2' do aplicativo."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o diretório de configuração antigo do servidor; por exemplo, 'JazzInstallDir/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o diretório de configuração antigo do servidor; por exemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o diretório de configuração antigo do servidor; por exemplo, 'JazzInstallDir/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "Não é possível localizar o comando repotools '$2' do aplicativo."
echo ""
echo "Verifique se o parâmetro -newApplicationHome '$3' está apontando para o novo diretório de configuração do servidor de aplicativos; por exemplo, 'JazzInstallDir/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo "Se estiver atualizando de uma liberação anterior, certifique-se de que tenha selecionado as raízes de contexto corretas.  Por exemplo, se estiver usando o Installation Manager, você deverá selecionar a opção de raiz de contexto $5 no painel "Context Root Options" .  Se selecionou acidentalmente uma opção diferente, você deverá reinstalar o produto com a opção de raiz de contexto $5."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -newApplicationHome '$3' está apontando para o novo diretório de configuração do servidor do JTS; por exemplo, 'JazzInstallDir/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo "Se estiver atualizando de uma liberação anterior, certifique-se de que tenha selecionado as raízes de contexto corretas.  Por exemplo, se estiver usando o Installation Manager, você deverá selecionar a opção de raiz de contexto $5 no painel "Context Root Options" .  Se selecionou acidentalmente uma opção diferente, você deverá reinstalar o produto com a opção de raiz de contexto $5."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "Não é possível localizar o comando repotools '$2' do JTS."
echo ""
echo "Verifique se o parâmetro -oldJTSHome '$3' está apontando para o diretório antigo de configuração do servidor do JTS; por exemplo, 'JazzInstallDir/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -oldJTSHome '$3' está apontando para o diretório antigo de configuração do servidor do JTS; por exemplo, 'JazzInstallDir/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "Não é possível localizar o comando repotools '$2' do JTS."
echo ""
echo "Verifique se o parâmetro -newJTSHome '$3' está apontando para o novo diretório de configuração do servidor do JTS; por exemplo, 'JazzInstallDir/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -newJTSHome '$3' está apontando para o novo diretório de configuração do servidor do JTS; por exemplo, 'JazzInstallDir/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Um arquivo tar contendo dados 2.x é necessário para o upgrade $2."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_dm )
echo ""
echo ""
echo "============================================="
echo "===    Upgrade do DM    ==="
echo "============================================="
echo ""
;;

BANNER_vvc )
echo ""
echo ""
echo "============================================"
echo "===    Upgrade do VVC    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "A última execução falhou na etapa inicial..."
;;

LAST_STEP_FAILED )
echo ""
echo "A última execução falhou na etapa $2..."
echo "Deseja reiniciar o upgrade a partir desta etapa ou de uma anterior?"
;;

ALREADY_RUN )
echo ""
echo "O upgrade já estava pronto e concluído com êxito..."
echo "Deseja reiniciar uma etapa nova ou uma específica?"
;;

LAST_STEP_PASSED )
echo ""
echo "A última execução foi interrompida com êxito na etapa $2..."
echo "Deseja reiniciar o upgrade a partir da etapa atual $3 ou de uma anterior?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Insira o número da etapa [$2-$3] a partir da qual deseja reiniciar o upgrade ou pressione [Enter] para Cancelar:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' não é um número. Insira um número de etapa válido."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' é um número inválido de etapa. Insira um número válido de etapa."
;;

MAX_STEP_NUMBER )
echo ""
echo "A última etapa é a etapa $2, portanto, não é possível reiniciar o upgrade a partir da etapa $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "A etapa $2 ainda não foi executada, portanto, não é possível reiniciar o upgrade na etapa $3."
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "Etapa 0: Eliminar tabelas"
echo "-------------------"
;;

STEP_0 )
echo "Etapa 0: Atualizar arquivos de configuração"
echo "---------------------------"
;;

STEP_1_ADD )
echo "Etapa 1: Incluir tabelas"
echo "------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "Etapa $2: Reconstruir índices de texto"
echo "----------------------------"
;;

JFS_INDICES_STEP )
echo "Etapa $2: Recriar índices de consulta e procura"
echo "-----------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Etapa 2: Atualizar o esquema de armazém de dados"
echo "-------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "O upgrade $2 falhou na etapa $3.  Corrija o problema e execute o script novamente, iniciando na etapa $3."
echo "" 
;;

OVERALL_MIGRATION_SUCCESS_DM )
echo ""
echo "O $2 upgrade foi executado com êxito.  Se também atualizou o JTS e o VVC, você poderá iniciar os servidores na implementação."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_VVC )
echo ""
echo "O upgrade $2 foi executado com êxito.  Se também tiver atualizado o JTS e qualquer aplicativo dependente (como o DM), você poderá iniciar os servidor na implementação."
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Diretório: $2"
echo "Comando:"
;;

ENTER_STEP_ACTION )
echo "Pressione Enter [E] para executar esta etapa, [S] para ignorar ou [Enter] para cancelar a execução do script:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' é uma entrada inválida; somente 'E', 'S' ou 'Enter' são permitidos"
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Um editor vi será aberto para permitir que verifique o arquivo teamserver.properties $2."
echo "Verifique se a raiz da URI Pública, denotada pela propriedade com.ibm.team.repository.server.webapp.url, está correta."
echo "Verifique se as propriedades do banco de dados estão corretas."
echo "Quando estiver pronto, salve as mudanças, se houver alguma, e feche o editor até continuar a execução do script."
echo ""
;;

PAUSE )
echo ""
echo "Insira [C] para continuar a execução ou pressione [Enter] para cancelar a execução do script:"
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' é uma entrada inválida; somente 'C' ou 'Enter' são permitidos"
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "Falha ao copiar índices de texto de '$2' a '$3'."
echo "Verifique a propriedade com.ibm.team.fulltext.indexLocation,"
echo "definida no arquivo teamserver.properties."
echo "Copie manualmente os índices de texto para esse diretório"
echo "ou execute repotools -rebuildTextIndices para reconstruí-los."
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERRO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Não há nenhuma URI Pública definida em"
echo "$3,"
echo "portanto não é possível iniciar o upgrade."
echo ""
echo "Deve haver uma URI Pública nesse arquivo, definida da seguinte forma:"
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "A propriedade com.ibm.team.repository.server.webapp.url da URI Pública deve estar presente no arquivo teamserver.properties."
echo "Inclua a propriedade no arquivo teamserver.properties da instalação antiga e configure o valor para ser a raiz da URI que todos os clientes usam para atingir o servidor."
echo "A raiz da URI Pública é essencial para o funcionamento adequado da nova instalação. O upgrade não será bem-sucedido sem essa propriedade.  "
echo "Para obter mais informações, consulte o tópico InfoCenter em 'Planejando as URIs'."
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERRO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Todas as URIs públicas definidas em"
echo "$3,"
echo "têm a linha comentada, portanto não é possível iniciar o upgrade."
echo ""
echo "Ele deve ter uma URI Pública não comentada neste arquivo, da seguinte forma:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "A propriedade com.ibm.team.repository.server.webapp.url da URI Pública deve estar presente no arquivo teamserver.properties."
echo "Inclua a propriedade no arquivo teamserver.properties da instalação antiga e configure o valor para ser a raiz da URI que todos os clientes usam para atingir o servidor."
echo "A raiz da URI Pública é essencial para o funcionamento adequado da nova instalação. O upgrade não será bem-sucedido sem essa propriedade."
echo "Para obter mais informações, consulte o tópico InfoCenter em 'Planejando as URIs'."
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "A raiz de contexto para o JTS está configurada em '$2'."
echo "A raiz de contexto para o aplicativo está configurada em '$3'."
echo "A raiz de contexto do jts e do aplicativo não podem ser as mesmas."
echo ""
;;

esac

}
